/*
 * $Id: //depot/prod/zephyr/lufthansaair/src/java/netapp/manage/NaAPIFailedException.java#1 $
 *
 * Copyright (c) 2001-2004 Network Appliance, Inc.
 * All rights reserved.
 *
 * ONTAPI Server stuff
 */

package netapp.manage;

/**
 *  Thrown to indicate that the API invocation failed. The server
 *  processed the request and returned a failure result including
 *  an errno code and a reason string.
 */
public class NaAPIFailedException extends NaException {

	private int _errno;
	private String _reason;

	/**
	 *  Constructs a new <code>NaAPIFailedException</code> with
	 *  the specified errno and reason message.
	 *
	 *  @param	errno		the error number.
	 *  @param	reason		the reason message.
	 */
	public NaAPIFailedException(int errno, String reason)
	{
		super(reason + " (errno=" + errno + ")");
		_errno = errno;
		_reason = reason;
	}

	/**
	 *  Return the errno value from an API result.  See the NaErrno class
	 *  which contains defined constants for the possible errno values. In
	 *  some cases, the server does not return an errno code (due to a bug)
	 *  and this function returns {@link NaErrno#EINTERNALERROR} as a
	 *  default.
	 *
	 *  @return	The errno value.
	 */
	public int getErrno()
	{
		return _errno;
	}

	/**
	 *  Return the reason for the API failure.
	 *
	 *  @return	The message which describes the reason for a failure.
	 */
	public String getReason()
	{
		return _reason;
	}
}
